body {
    margin: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    background-color: #f8f9fa;
    position: absolute;
}


.markdown-body {
    margin-top: 2%;
    margin-left: "<%markdown_body_left%>";
    margin-right: "<%markdown_body_right%>";
    padding: 20px 50px;
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%;
    line-height: 1.5;
    /* color: #24292e; */
    font-family: "<%font_family%>";
    font-size: "<%font_size%>";
    letter-spacing: "<%letter_spacing%>";
    line-height: 1.5;
    word-wrap: break-word;
    border-radius: 10px;
    box-shadow: "<%markdown_box_shadow%>";
    background-color: "<%markdown_bg_color%>";
}

.light {
    background-color: #eee;
    color: #3c4858;
}

.dark {
    background-color: #181c27;
    color: #c4c6c9;
}


.markdown-light {
    background-color: "<%markdown_bg_color%>";
}

.markdown-light h1,
.markdown-light h2,
.markdown-light h3,
.markdown-light h4,
.markdown-light h5,
.markdown-light h6 {
    color: "<%hash_header_color%>";
}

.markdown-light a {
    color: "<%post_link_color%>";
    transition: all 0.8s;
}

.markdown-light a:hover {
    color: "<%link_hover_color%>";
    transition: all 0.8s;
}

.markdown-body strong {
    font-weight: inherit;
    font-weight: bolder;
}

.markdown-body h1 {
    font-size: 2em;
    margin: 0.67em 0;
}

.markdown-body img {
    border-style: none;
}

a {
    color: rgb(4, 105, 221);
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}

blockquote {
    margin: 0;
    margin-top: 10px;
    margin-bottom: 16px;
    padding: 1px 1em;
    color: #6a737d;
    border-left: 0.25em solid #dfe2e5;
    border-radius: 3px;
}

.markdown-body code,
.markdown-body kbd,
.markdown-body pre {
    font-family: Monaco, Consolas, Liberation Mono, Menlo, monospace;
    font-size: 15px;
}

.markdown-body strong {
    font-weight: 600;
}

.markdown-body hr {
    height: 0;
    margin: 25px 0;
    overflow: hidden;
    background: transparent;
    border: 0;
    border-bottom: 2px solid #dfe2e5;
}

.markdown-body hr:after,
.markdown-body hr:before {
    display: table;
    content: "";
}

.markdown-body blockquote,
.markdown-body details,
.markdown-body dl,
.markdown-body ol,
.markdown-body p,
.markdown-body table,
.markdown-body ul {
    margin-top: 0;
    margin-bottom: 16px;
    cursor: pointer;
}

.markdown-body pre {
    margin-top: 5px;
    margin-bottom: 16px;
    padding: 16px;
    overflow: auto;
    font-size: 85%;
    /* max-height: 600px; */
    line-height: 1.45;
    background-color: #f6f8fa;
    border-radius: 3px;
    word-wrap: normal;
    box-shadow: "<%markdown_code_box_shadow%>";
    cursor: pointer;
}

.markdown-body code {
    padding: 0.2em 0.4em;
    margin: 0;
    font-size: 95%;
    background-color: rgba(27, 31, 35, 0.05);
    border-radius: 3px;
}

.markdown-body pre>code {
    padding: 0;
    margin: 0;
    font-size: 100%;
    word-break: normal;
    white-space: pre;
    background: transparent;
    border: 0;
}

.markdown-body pre code {
    max-width: 100%;
    padding: 0;
    margin: 0;
    overflow: visible;
    line-height: inherit;
    word-wrap: normal;
    background-color: initial;
    border: 0;
    cursor: pointer;
}

/* ul lo related css */

.markdown-body ul {
    margin-top: 0;
    margin-bottom: 8px;
    padding-left: 1.5em;
}

.markdown-body ol {
    margin-top: 0;
    margin-bottom: 8px;
    padding-left: 2.3em;
}


.markdown-body ol ul,
.markdown-body ul ul {
    padding-left: 1em;
    margin-top: 10px;
}

.markdown-body ol ol,
.markdown-body ul ol {
    padding-left: 1.75em;
    margin-top: 10px;
}

.markdown-body ul p,
.markdown-body ol p {
    margin-bottom: 10px;
}

.markdown-body ol li blockquote {
    margin-top: 10px;
}

.markdown-body ul li blockquote {
    margin-top: 10px;
}

.markdown-body li {
    word-wrap: break-all;
}

.markdown-body li>p {
    margin-top: 10px;
}

.markdown-body li+li {
    margin-top: 0.25em;
}

ul>li>ul>li,
ol>li>ol>li,
ul>li>ol>li,
ol>li>ul>li {
    margin-top: 0;
    margin-top: 10px;
}

.markdown-body ol li blockquote {
    margin-top: 10px;
}

.markdown-body ul li blockquote {
    margin-top: 10px;
}

/* ul 后面的文字加一个间距 */
.markdown-body>ul~p,
.markdown-body>ol~p,
.markdown-body>ul~blockquote,
.markdown-body>ol~blockquote .markdown-body>ul~pre,
.markdown-body>ol~pre,
.markdown-body>ul~a,
.markdown-body>ol~a {
    margin-top: 16px;
}

.markdown-body table {
    border-spacing: 0;
    border-collapse: collapse;
}

.markdown-body table th {
    font-weight: 600;
    white-space: nowrap;
}

.markdown-body table td,
.markdown-body table th {
    padding: 6px 13px;
    border: 1px solid #dfe2e5;
}

.markdown-body table tr {
    background-color: #fff;
    border-top: 1px solid #c6cbd1;
}

.markdown-body table tr:nth-child(2n) {
    background-color: #f6f8fa;
}

.markdown-body table {
    max-width: 100%;
    border-spacing: 0;
    border-collapse: collapse;
}

.markdown-body h1,
.markdown-body h2,
.markdown-body h3,
.markdown-body h4,
.markdown-body h5,
.markdown-body h6 {
    margin-top: 24px;
    margin-bottom: 16px;
    font-weight: 600;
    line-height: 1.25;
}

.markdown-body>ul>li:has(input) {
    padding-left: 0;
    margin-bottom: 0;
}

.markdown-body ul>li:has(input)>ul {
    list-style-type: none;
    padding-left: 8px;
}

.markdown-body img {
    max-width: 80%;
    max-height: 500px;
    display: block;
    margin: 0 auto;
    box-shadow: "<%markdown_picture_box_shadow%>";
    border-radius: 5px;
}

.markdown-body .pic-small {
    max-width: 40%;
    max-height: 300px;
}

.markdown-body .pic-middle {
    max-width: 60%;
    max-height: 400px;
}

.markdown-body pre {
    position: relative;
}

.markdown-body pre #code_copy {
    display: inline-flex;
    align-items: center;
    justify-content: center;
    width: 32px;
    height: 32px;
    position: absolute;
    top: 5px;
    right: 8px;
    background: #0b0b0b;
    color: #9198a1;
    padding: 6px;
    border-radius: 6px;
    cursor: pointer;
    z-index: 2;
    transition: background 0.12s ease, border-color 0.12s ease, transform 0.1s ease, color 0.12s ease;
}

.markdown-body pre #code_copy:hover {
    background: #121212;
    border-color: #2a2a2a;
    transform: translateY(-0.5px);
}


.markdown-body kbd {
    display: inline-block;
    padding: 5px 5px;
    font: 11px "Monaco", Consolas, "Liberation Mono", Menlo, Courier, monospace;
    line-height: 10px;
    color: #444d56;
    vertical-align: middle;
    background-color: #fafbfc;
    border: solid 1px #d1d5da;
    border-bottom-color: #c6cbd1;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 -1px 0 #c6cbd1;
    box-shadow: inset 0 -1px 0 #c6cbd1;
}

.markdown-light ::selection {
    background-color: "<%text_hover_color%>";
}

.markdown-body pre code ::selection {
    background-color: #264f78;
}

.markdown-body h1,
.markdown-body h2 {
    padding-bottom: 0.3em;
    border-bottom: 1px solid #eaecef;
}

.markdown-body .icon-note,
.markdown-body .icon-tip,
.markdown-body .icon-warning,
.markdown-body .icon-important,
.markdown-body .icon-caution,
.markdown-body .icon-question {
    margin-left: 0;
    margin-right: 1%;
    box-shadow: none;
    /* use default display instead of block */
    display: inline;
}

.markdown-body blockquote div {
    align-items: center;
    display: flex;
    justify-content: left;
    margin-bottom: 5px;
    margin-top: 5px;
}

.markdown-body blockquote p {
    margin-bottom: 5px;
    margin-top: 5px;
    margin-left: 5px;
}

.changeMode {
    position: absolute;
    right: 50px;
    top: 50px;
    padding: 5px;
    border-radius: 50%;
    background-color: #e3e3e3;
    box-shadow: rgba(0, 0, 0, 0.25) 0px 54px 55px,
        rgba(0, 0, 0, 0.12) 0px -12px 30px, rgba(0, 0, 0, 0.12) 0px 4px 6px,
        rgba(0, 0, 0, 0.17) 0px 12px 13px, rgba(0, 0, 0, 0.09) 0px -3px 5px;
    cursor: pointer;
}

.change-article {
    font-family: "<%font_family%>";
    border: 0;
    width: 100%;
    margin-right: 20%;
    height: 100px;
    margin-top: 50px;
    border-radius: 10px;
    transition: all 0.5s;
    box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px;
}

.change-dark {
    background-color: #6a737d;
    color: #f8f9fa;
}

/* 切换文章按钮 */
.next-front {
    position: fixed;
    right: "<%button_right%>";
    top: "<%button_top%>";
    width: "<%button_width%>";
    /* white-space:nowrap; */
}

.next-front .change-article:hover {
    cursor: pointer;
    font-weight: bolder;
    transition: all 0.5s;
    box-shadow: rgba(100, 100, 111, 0.4) 0px 7px 29px 0px;
}

.next-front .change-article:active {
    width: 95%;
    height: 90px;
}

/* 对目录树的调整 */

.dir-tree::-webkit-scrollbar {
    display: none;
    /* Chrome Safari */
}

.dir-tree {
    font-family: "<%font_family%>";
    position: fixed;
    left: "<%dir_left%>";
    top: "<%dir_top%>";
    width: "<%dir_width%>";
    max-width: 200px;
    box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px;
    background-color: #f6f8fa;
    border-radius: 10px;
    max-height: "<%dir_height%>";
    overflow: auto;
    scrollbar-width: none;
    /* Firefox */
    -ms-overflow-style: none;
    /* IE 10+ */
    text-overflow: ellipsis;
    /*  过长文字省略号 */
    white-space: nowrap;
    /*禁止文字折行*/
}

.dir-tree ul {
    font-family: "<%font_family%>";
    font-size: "<%dir_item_font_size%>";
    letter-spacing: "<%letter_spacing%>";
    margin-top: "<%dir_item_margin%>";
    margin-bottom: "<%dir_item_margin%>";
    margin-left: "<%dir_item_margin_left%>";
    list-style: none;
    position: relative;
    /* box-shadow: rgba(149, 157, 165, 0.2) 0px 8px 24px; */
}

.dir-tree ul li a {
    display: inline-block;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

.dir-tree ul ul {
    overflow: hidden;
    transform-origin: top;
}

.dir-tree ul ul.collapsed {
    transform: scaleY(0);
    opacity: 0;
    height: 0;
    padding-top: 0;
    padding-bottom: 0;
    margin-top: 0;
    margin-bottom: 0;
}

.dir-tree ul ul li {
    font-family: "<%font_family%>";
    letter-spacing: "<%letter_spacing%>";
    font-size: "<%dir_second_item_font_size%>";
    margin-left: -10px;
    margin-top: -10px;
    /* margin-bottom: 10px; */
    padding-left: "<%dir_second_item_margin_left%>";
    padding-top: 10px;
    padding-bottom: "<%dir_second_item_margin%>";
    border-radius: 10px;
    /* padding-right: -10px; */
}

/* .dir-tree ul ul li:hover {
  background-color: "<%body_bg_color%>";
} */

.dir-tree ul ul li a {
    color: "<%dir_second_tree_color%>";
}

.dir-tree ul ul li a:hover {
    color: "<%dir_second_tree_hover_color%>";
}

.link-active {
    font-weight: bold !important;
    border-bottom: 2px solid #555;
    padding-bottom: 2px;
}

.link-active-dark {
    font-weight: bold !important;
    border-bottom: 2px solid #f3f3f3;
    padding-bottom: 2px;
}

/* 图片下的文字的样式 */

.markdown-body p>p {
    color: "<%picture_text_color%>";
    margin-top: 10px;
    text-align: center;
    line-height: 100%;
}

.preview-image {
    position: fixed;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    width: "<%image_preview_width%>";
    z-index: 200;
}

#black_overlay {
    display: none;
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: "<%picture_preview_bg_color%>";
    z-index: 100;
}

.zood {
    width: 100%;
    text-align: center;
    vertical-align: middle;
    margin-top: 10px;
    /* display: flex; */
}

.zood a {
    text-decoration: none;
    color: grey;
    /* display: block; */
}

.zood a:hover {
    text-decoration: underline;
}


.markdown-body ul:has(input[type="checkbox"]) {
    list-style-type: none;
    padding-left: 0.5em;
    margin-bottom: 8px;
}

.markdown-body input[type="checkbox"] {
    margin-right: 0.5em;
    /* 复选框和文本之间的间距 */
}

/* 对小标题索引树的调整 */

.header-navigator {
    display: none;
    position: fixed;
    width: "<%navigator_max_width%>";
    left: "<%navigator_left%>";
    top: "<%navigator_top%>";
    font-family: "<%font_family%>";
    font-size: "<%dir_item_font_size%>";
    letter-spacing: "<%letter_spacing%>";
    scrollbar-width: none;
    /* Firefox */
    -ms-overflow-style: none;
    /* IE 10+ */
    text-overflow: ellipsis;
    /*  过长文字省略号 */
    white-space: nowrap;
    /*禁止文字折行*/
    list-style: none;
    max-height: 50%;
    overflow: auto;
    border-left: 2px solid #e0e0e0;
    /* 添加左侧灰色竖线 */
    padding-left: -5px;
    /* 增加左侧内边距,与竖线保持适当距离 */
}

.header-navigator::-webkit-scrollbar {
    display: none;
    /* Chrome Safari */
}

.header-navigator a {
    color: "<%text_color%>";
    text-decoration: none;
}

.header-navigator a:hover {
    font-weight: bolder;
}

.header-navigator ul {
    font-family: "<%font_family%>";
    font-size: "<%navigator_item_font_size%>";
    letter-spacing: "<%letter_spacing%>";
    margin-top: "<%navigator_margin%>";
    margin-bottom: "<%navigator_margin%>";
    margin-left: "<%navigator_item_margin_left%>";
    list-style: none;
    position: relative;
}

.header-navigator ul ul {
    margin-left: -30px;
}

.header-navigator a {
    display: inline-block;
    max-width: 100%;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}

pre[class^="language-"] {
    background: #0b0b0b;
    color: #C1CCCC;
}

pre[class^="language-"] ::selection {
    background-color: #264f78;
}


.lb-loader,
.lightbox {
    text-align: center;
    line-height: 0;
    position: absolute;
    left: 0
}

body.lb-disable-scrolling {
    overflow: hidden
}

.lightboxOverlay {
    position: absolute;
    top: 0;
    left: 0;
    z-index: 9999;
    background-color: #000;
    filter: alpha(Opacity=80);
    opacity: .8;
    display: none
}

.lightbox {
    width: 100%;
    z-index: 10000;
    font-weight: 400;
    outline: 0
}

.lightbox .lb-image {
    display: block;
    height: auto;
    max-width: inherit;
    max-height: none;
    border-radius: 3px;
    border: 4px solid #fff
}

.lightbox a img {
    border: none
}

.lb-outerContainer {
    position: relative;
    width: 250px;
    height: 250px;
    margin: 0 auto;
    border-radius: 4px;
    background-color: #fff
}

.lb-outerContainer:after {
    content: "";
    display: table;
    clear: both
}

.lb-loader {
    top: 43%;
    height: 25%;
    width: 100%
}

.lb-cancel {
    display: block;
    width: 32px;
    height: 32px;
    margin: 0 auto;
}

.lb-nav {
    position: absolute;
    top: 0;
    left: 0;
    height: 100%;
    width: 100%;
    z-index: 10
}

.lb-container>.nav {
    left: 0
}

.lb-nav a {
    outline: 0;
    background-image: url(data:image/gif;base64,R0lGODlhAQABAPAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw==)
}

.lb-next,
.lb-prev {
    height: 100%;
    cursor: pointer;
    display: block
}

.lb-nav a.lb-prev {
    width: 34%;
    left: 0;
    float: left;
    filter: alpha(Opacity=0);
    opacity: 0;
    -webkit-transition: opacity .6s;
    -moz-transition: opacity .6s;
    -o-transition: opacity .6s;
    transition: opacity .6s
}

.lb-nav a.lb-prev:hover {
    filter: alpha(Opacity=100);
    opacity: 1
}

.lb-nav a.lb-next {
    width: 64%;
    right: 0;
    float: right;
    filter: alpha(Opacity=0);
    opacity: 0;
    -webkit-transition: opacity .6s;
    -moz-transition: opacity .6s;
    -o-transition: opacity .6s;
    transition: opacity .6s
}

.lb-nav a.lb-next:hover {
    filter: alpha(Opacity=100);
    opacity: 1
}

.lb-dataContainer {
    margin: 0 auto;
    padding-top: 5px;
    width: 100%;
    border-bottom-left-radius: 4px;
    border-bottom-right-radius: 4px
}

.lb-dataContainer:after {
    content: "";
    display: table;
    clear: both
}

.lb-data {
    padding: 0 4px;
    color: #ccc
}

.lb-data .lb-details {
    width: 85%;
    float: left;
    text-align: left;
    line-height: 1.1em
}

.lb-data .lb-caption {
    font-size: 13px;
    font-weight: 700;
    line-height: 1em
}

.lb-data .lb-caption a {
    color: #4ae
}

.lb-data .lb-number {
    display: block;
    clear: left;
    padding-bottom: 1em;
    font-size: 12px;
    color: #999
}

.lb-data .lb-close {
    display: block;
    float: right;
    width: 30px;
    height: 30px;
    text-align: right;
    outline: 0;
    filter: alpha(Opacity=70);
    opacity: .7;
    -webkit-transition: opacity .2s;
    -moz-transition: opacity .2s;
    -o-transition: opacity .2s;
    transition: opacity .2s
}

.lb-data .lb-close:hover {
    cursor: pointer;
    filter: alpha(Opacity=100);
    opacity: 1
}

/* 对于 phone & ipad 单独适配 */

@media screen and (max-width: 768px) {
    .dir-tree {
        display: none;
    }

    .markdown-body {
        margin-left: 0;
        margin-top: 0;
        margin-right: 0;
        margin-bottom: 0;
        border-radius: initial;
    }

    .next-front {
        position: relative;
        right: initial;
        top: initial;
        width: initial;
        display: flex;
        justify-content: center;
        align-items: center;
        /* right: 4%;
        width: 5%;
        top: 60%; */
    }

    .change-article {
        margin: initial;
        border-radius: initial;
        /* 边框颜色 */
        border: 1px solid rgba(149, 157, 165, 0.2);
    }

    .zood {
        display: none;
    }
}

.dir-tree a {
    text-decoration: none;
    color: "<%dir_tree_color%>";
    /* https://www.bilibili.com/video/BV1Dc41147sW */
    /* background: linear-gradient(to right, #000, #000) no-repeat right bottom;
    background-size: 0 2px;
    transition: background-size 1000ms; */
}

.dir-tree a:hover {
    font-weight: bold;
    color: "<%dir_tree_hover_color%>";
    /* background-position-x: left;
    background-size: 100% 2px; */
}

/* 引用部分样式 */
.references-tabs-container {
    margin-top: 40px;
    margin-bottom: 20px;
    border: 1px solid #e1e4e8;
    border-radius: 8px;
    background-color: #ffffff;
    overflow: hidden;
}

/* 选项卡导航 */
.references-tabs-nav {
    display: flex;
    background-color: #f6f8fa;
    border-bottom: 1px solid #e1e4e8;
}

.references-tab-btn {
    flex: 1;
    padding: 12px 16px;
    border: none;
    background: none;
    color: #656d76;
    font-size: 14px;
    font-weight: 500;
    cursor: pointer;
    border-bottom: 3px solid transparent;
    transition: all 0.2s ease;
    position: relative;
}

.references-tab-btn:hover {
    color: #24292f;
    background-color: #f3f4f6;
}

.references-tab-btn.active {
    color: #0969da;
    border-bottom-color: #0969da;
    background-color: #ffffff;
}

/* 选项卡内容 */
.references-tabs-content {
    position: relative;
}

.references-tab-pane {
    display: none;
    padding: 20px;
}

.references-tab-pane.active {
    display: block;
}

.reference-list {
    list-style: none;
    padding-left: 0 !important;
    margin: 0;
}

.reference-list li {
    margin-bottom: 8px;
}

.reference-list a {
    text-decoration: none;
    color: #0969da;
    font-weight: 500;
    display: inline-flex;
    align-items: center;
    gap: 10px;
    font-size: 14px;
    width: 100%;
    padding: 12px 4px;
    background-color: #f3f4f6;
    border-radius: 6px;
    transition: all 0.2s ease;
}

.reference-list a:hover {
    background-color: #e5e7eb;
    transform: none;
    box-shadow: none;
    text-decoration: none;
    color: #0969da;
}

.reference-icon {
    width: 18px;
    height: 18px;
    display: inline-block;
    flex-shrink: 0;
    background-size: contain;
    background-repeat: no-repeat;
    background-position: center;
    /* 简单的蓝色文档图标 */
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' width='24' height='24' fill='none' stroke='%230969da' stroke-width='2' stroke-linecap='round' stroke-linejoin='round' style='opacity:1;'%3E%3Cpath d='M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z'/%3E%3Cpath d='M14 2v4a2 2 0 0 0 2 2h4M10 9H8m8 4H8m8 4H8'/%3E%3C/svg%3E");
    margin-left: 5px;
}
